pyxmpp.streamtls

Package pyxmpp :: Module streamtls |
[hide private]

# Module streamtls

source code

TLS support for XMPP streams.

Normative reference:
  - RFC 3920

Classes | [hide private]
| TLSSettings Storage for TLS-related settings of an XMPP stream.
| StreamTLSMixIn Mix-in class providing TLS support for an XMPP stream.

Functions | [hide private]
_count_args(callable) Utility function to count expected arguments of a callable | source code

Variables | [hide private]
| __revision__ = ``'``$Id: streamtls.py 701 2010-04-03 15:43:50Z jaj``...``
| TLS_NS = ``'``urn:ietf:params:xml:ns:xmpp-tls``'``
| tls_available = `True`
| __package__ = ``'``pyxmpp``'``

Imports: socket, sys, errno, logging, ssl, warnings, inspect, SSLError, StreamBase, STREAM_NS, FatalStreamError, StreamEncryptionRequired, TLSNegotiationFailed, TLSError, TLSNegotiatedButNotAvailableError, JID

Variables Details | [hide private]

  ### __revision__ Value:
      '$Id: streamtls.py 701 2010-04-03 15:43:50Z jajcus $'